no_jacobian_mapping

Function no_jacobian_mapping 

pub fn no_jacobian_mapping<T>() -> Option<JacobianMappingType<T>>
Helper for the generic case where no Jacobian mapping is provided.

This is useful when the scalar type is not the default f64, for example when using f32.