SolverStatus

Struct SolverStatus 

pub struct SolverStatus<T = f64>
where T: Float,
{ /* private fields */ }
Solver status

This structure contais information about the solver status. Instances of SolverStatus are returned by optimizers.

Implementations

Source

impl<T: Float> SolverStatus<T>

pub fn new( exit_status: ExitStatus, num_iter: usize, solve_time: Duration, fpr_norm: T, cost_value: T, ) -> SolverStatus<T>

Constructs a new instance of SolverStatus

Arguments
  • converged whether the algorithm has converged to a solution up to the specified tolerance
  • num_iter number of iterations
  • fpr_norm norm of the fixed-point residual; a gauge of the solution quality
  • cost_value the value of the cost function at the solution
pub fn has_converged(&self) -> bool

whether the algorithm has converged

pub fn iterations(&self) -> usize

number of iterations taken by the algorithm

pub fn solve_time(&self) -> Duration

total execution time

pub fn norm_fpr(&self) -> T

norm of the fixed point residual

pub fn cost_value(&self) -> T

value of the cost at the solution

pub fn exit_status(&self) -> ExitStatus

exit status of solver