Function optimization_engine::matrix_operations::sum
source · pub fn sum<T>(a: &[T]) -> Twhere
T: Float + Sum<T> + Mul<T, Output = T>,Expand description
Calculate the sum of all elements of a vector
pub fn sum<T>(a: &[T]) -> Twhere
T: Float + Sum<T> + Mul<T, Output = T>,Calculate the sum of all elements of a vector