pub fn no_set<T>() -> Option<NoConstraints>Expand description
Helper for the generic case where no set is provided.
This is useful when the scalar type is not the default f64, for example
when using f32.
pub fn no_set<T>() -> Option<NoConstraints>Helper for the generic case where no set is provided.
This is useful when the scalar type is not the default f64, for example
when using f32.